@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-import acfun_upload
+from .acfun import AcFun
 
 __author__ = "Aruelius"
 __email__ = "aurelius@aliyun.com"
-__version__ = "0.0.2"
+__version__ = "0.0.3"
